@@ -1,7 +1,7 @@
 package RPC::Switch::Client;
 use Mojo::Base -base;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 #
 # Mojo's default reactor uses EV, and EV does not play nice with signals
@@ -648,9 +648,30 @@ sub _daemonize {
 
 	use POSIX;
 
+	# handles for IPC and checking success of child
+	pipe my ( $in, $out );
+
 	# Fork and kill parent
 	die "Can't fork: $!" unless defined(my $pid = fork);
-	exit 0 if $pid;
+
+	if ($pid) {
+
+		# read if child was successful before exiting
+
+		CORE::close $out;
+
+		my $success = readline $in;
+
+		CORE::close $in;
+
+		exit ($success ? 0 : 1);
+
+	} else {
+
+		# close the handle that the parent will read on
+		CORE::close $in;
+
+	}
 
 	_create_pidfile($pidfile);
 
@@ -660,13 +681,16 @@ sub _daemonize {
 	open STDIN,  '</dev/null';
 	open STDOUT, '>/dev/null';
 	open STDERR, '>&STDOUT';
+
+	say $out 1; # notify success 
+
+	CORE::close $out;
 }
 
 sub _create_pidfile {
 	my $pidfile = shift;
 
 	if ($pidfile) {
-
 		open my $pid_fh, '>', $pidfile 
 			or die "Unable to open pid file for writing '$pidfile': $!";
 
